@@ -75,7 +75,6 @@ where
         append_stmts: Default::default(),
         lits: Default::default(),
         vars_for_inlining: Default::default(),
-        inlined_vars: Default::default(),
         vars_for_prop_hoisting: Default::default(),
         simple_props: Default::default(),
         _simple_array_values: Default::default(),
@@ -200,7 +199,6 @@ struct Optimizer<'a, M> {
     lits: AHashMap<Id, Box<Expr>>,
 
     vars_for_inlining: AHashMap<Id, Box<Expr>>,
-    inlined_vars: AHashMap<Id, Box<Expr>>,
 
     vars_for_prop_hoisting: AHashMap<Id, Box<Expr>>,
     /// Used for `hoist_props`.
@@ -1193,13 +1191,14 @@ where
 
     /// `new RegExp("([Sap]+)", "ig")` => `/([Sap]+)/gi`
     fn compress_regexp(&mut self, e: &mut Expr) {
-        let span = e.span();
-        let args = match e {
-            Expr::New(NewExpr { callee, args, .. }) => match &**callee {
+        let (span, args) = match e {
+            Expr::New(NewExpr {
+                span, callee, args, ..
+            }) => match &**callee {
                 Expr::Ident(Ident {
                     sym: js_word!("RegExp"),
                     ..
-                }) => args,
+                }) => (*span, args),
                 _ => return,
             },
             _ => return,
@@ -2165,11 +2164,6 @@ where
         };
         self.with_ctx(ctx).handle_stmt_likes(stmts);
 
-        stmts.visit_mut_with(&mut MultiReplacer {
-            vars: take(&mut self.inlined_vars),
-            changed: false,
-        });
-
         stmts.visit_mut_with(&mut MultiReplacer {
             vars: take(&mut self.vars_for_inlining),
             changed: false,
