@@ -6,6 +6,7 @@ use swc_ecma_visit::{noop_visit_type, Visit, VisitWith};
 use tracing::trace;
 
 use self::scope::Scope;
+use super::rename_map::RenameMap;
 
 mod scope;
 
@@ -17,12 +18,12 @@ pub(super) struct Analyzer {
 
 impl Analyzer {
     pub(super) fn into_rename_map(mut self, preserved: &AHashSet<Id>) -> AHashMap<Id, JsWord> {
-        let mut map = AHashMap::default();
+        let mut map = RenameMap::default();
 
         let preserved_symbols = preserved.iter().cloned().map(|v| v.0).collect();
         self.scope.rename(&mut map, preserved, &preserved_symbols);
 
-        map
+        map.into_map()
     }
 
     fn add_decl(&mut self, id: Id) {
