@@ -1,5 +1,7 @@
+use swc_common::{SyntaxContext, DUMMY_SP};
 use swc_ecma_ast::*;
 use swc_ecma_transforms::hygiene::rename;
+use swc_ecma_utils::UsageFinder;
 use swc_ecma_visit::{noop_visit_mut_type, VisitMut, VisitMutWith, VisitWith};
 
 use super::{analyzer::Analyzer, preserver::idents_to_preserve};
@@ -9,18 +11,40 @@ pub(crate) fn name_mangler(
     options: MangleOptions,
     _char_freq_info: CharFreqInfo,
     _marks: Marks,
+    top_level_ctxt: SyntaxContext,
 ) -> impl VisitMut {
-    Mangler { options }
+    Mangler {
+        options,
+        top_level_ctxt,
+    }
 }
 
 struct Mangler {
     options: MangleOptions,
+    /// Used to check `eval`.
+    top_level_ctxt: SyntaxContext,
+}
+
+impl Mangler {
+    fn contains_eval<N>(&self, node: &N) -> bool
+    where
+        N: for<'aa> VisitWith<UsageFinder<'aa>>,
+    {
+        UsageFinder::find(
+            &Ident::new("eval".into(), DUMMY_SP.with_ctxt(self.top_level_ctxt)),
+            node,
+        )
+    }
 }
 
 impl VisitMut for Mangler {
     noop_visit_mut_type!();
 
     fn visit_mut_module(&mut self, m: &mut Module) {
+        if self.contains_eval(m) {
+            return;
+        }
+
         let preserved = idents_to_preserve(self.options.clone(), &*m);
 
         let map = {
@@ -37,6 +61,10 @@ impl VisitMut for Mangler {
     }
 
     fn visit_mut_script(&mut self, s: &mut Script) {
+        if self.contains_eval(s) {
+            return;
+        }
+
         let preserved = idents_to_preserve(self.options.clone(), &*s);
 
         let map = {
